==> kmyfirewall_1.0.orig.tar.gz: kmyfirewall-1.0/kmyfirewall/kmfwidgets/kmfnewdocdlg.h <==
/***************************************************************************
    begin                : Thu Apr 17 2003
    copyright            : (C) 2003 by Christian Hubinger
    email                : chubinger@gmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFNEWDOCDLG_H
#define KMFNEWDOCDLG_H

#include <qwidget.h>
#include <kdemacros.h>
#include "kmyfirewallnewdocument.h"

/**
  *@author Christian Hubinger
  */

class KDE_EXPORT KMFNewDocDlg : public KMyFirewallNewDocument  {
   Q_OBJECT
public: 
	KMFNewDocDlg(QWidget *parent=0, const char *name=0, WFlags fl = 0);
	~KMFNewDocDlg();


private slots:
	void reject();
	void loadEmpty();
	void loadWizard();
	void loadTemplate();
	void loadSaved();
  void slotHelp();
signals:
	void sigNewDocLoadWizard();
	void sigNewDocLoadTemplate();
	void sigNewDocLoadSaved();
	void sigNewDocLoadEmpty();
};

#endif

==> kmyfirewall_1.1.1.orig.tar.gz: kmyfirewall-1.1.1/kmyfirewall/kmfwidgets/kmfnewdocdlg.h <==
/***************************************************************************
    begin                : Thu Apr 17 2003
    copyright            : (C) 2003 by Christian Hubinger
    email                : chubinger@irrsinnig.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFNEWDOCDLG_H
#define KMFNEWDOCDLG_H

#include <qwidget.h>
#include <kdemacros.h>
#include "kmyfirewallnewdocument.h"


/**
  *@author Christian Hubinger
  */

class QKeyEvent;
namespace KMF {
class KDE_EXPORT KMFNewDocDlg : public KMyFirewallNewDocument  {
   Q_OBJECT
public: 
	KMFNewDocDlg(QWidget *parent=0, const char *name=0, WFlags fl = 0);
	~KMFNewDocDlg();



private slots:
	void reject();
	void loadEmpty();
	void loadWizard();
	void loadTemplate();
	void loadSaved();
  void slotHelp();
signals:
	void sigNewDocLoadWizard();
	void sigNewDocLoadTemplate();
	void sigNewDocLoadSaved();
	void sigNewDocLoadEmpty();
};
}
#endif
